@@ -54,7 +54,7 @@ Sample usage:
 """
 
 __author__ = "Gilad Raphaelli"
-__version__ = "0.4.3"
+__version__ = "0.4.4"
 
 try:
 	import hashlib
@@ -122,12 +122,17 @@ class API:
 		self.key = key
 		self.secret = secret
 
-	def execute_method(self, method, args={}, sign=True):
+	def execute_method(self, method, args=None, sign=True):
 		""" Given a Flickr API method and arguments, construct a Flickr.API.Request and return a urllib2.addinfourl """
+		if args is None:
+			args = {}
 		args['method'] = method
 		return self.execute_request(Request(**args), sign)
 
-	def execute_upload(self, filename, args={}):
+	def execute_upload(self, filename, args=None):
+		""" Given a Flickr API method and arguments, construct a Flickr.API.Request for uploading and return a urllib2.addinfourl """
+		if args is None:
+			args = {}
 		try:
 			photo = open(filename, mode='rb')
 			args['photo'] = photo
